SystemOrganization addCategory: #'Neo-JSON-VAST-Tests'!

!Number methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 2/1/2018 09:42'!
closeTo: num
	"Tell whether the receiver and arguments are close from each."

	num isFloat ifTrue: [ ^ num closeTo: self asFloat ].
	^ [ self = num ] on: Error do: [ :ex | false ]! !

!Number methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num precision: aPrecision
	"are these two numbers close?"

	num isFloat ifTrue: [ ^ num closeTo: self asFloat precision: aPrecision ].
	^ [ self = num ] ifError: [ false ]! !

!Number methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'tbn 10/24/2012 15:32'!
hour
 
 	^ self hours! !

!Number methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'brp 5/16/2003 07:56'!
hours
 
 	^ Duration hours: self! !

!KeyedCollection classSide methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 11:32'!
newFromPairs: anArray
	"Answer an instance of me associating (anArray at: i) to (anArray at: i+1)
	 for each odd i.  anArray must have an even number of entries."

	"Dictionary newFromPairs: {'Red' . Color red . 'Blue' . Color blue . 'Green' . Color green}."

	| newDictionary |
	newDictionary := self new: anArray size / 2.
	1 to: anArray size - 1 by: 2 do: [ :i | newDictionary at: (anArray at: i) put: (anArray at: i + 1) ].
	^ newDictionary! !

!KeyedCollection methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 2/1/2018 09:57'!
removeAll

	self keysDo: [ :aKey | self removeKey: aKey ]! !

!String methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 17:02'!
includesSubString: aString

	^ (self indexOfSubCollection: aString startingAt: 1) ~~ 0
! !

!Time class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'PeterHugossonMiller 9/2/2009 16:01'!
fromString: aString
	^ self readFrom: aString readStream.
! !

!Time class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 2/2/2018 15:52'!
readFrom: aStream
	"Read a Time from the stream in the form:
		<hour>:<minute>:<second>.<nseconds> <am/pm>
	<minute>, <second> or <am/pm> may be omitted.  e.g. 1:59:30 pm; 8AM; 15:30"

	| hour minute second ampm nanos power |
	hour := Integer readFrom: aStream.
	minute := second := nanos := 0.
	(aStream peekFor: $:) 
		ifTrue: [
			minute := Integer readFrom: aStream.
			(aStream peekFor: $:) 
				ifTrue: [
					second := Integer readFrom: aStream.
					(aStream peekFor: $.)
						ifTrue: [ 
							power := 1.
							[ aStream atEnd not and: [ aStream peek isDigit ] ]
								whileTrue: [  
									nanos := nanos * 10 + aStream next digitValue.
									power := power * 10 ].
							nanos := nanos / power * 1000000000 ] ] ].
	aStream skipSeparators.
	(aStream atEnd not and: [ 'APap' includes: aStream peek ]) 
		ifTrue: [
			ampm := aStream next asLowercase.
			(ampm = $p and: [ hour < 12 ]) ifTrue: [ hour := hour + 12 ].
			(ampm = $a and: [ hour = 12 ]) ifTrue: [ hour := 0 ].
			(aStream peekFor: $m) ifFalse: [ aStream peekFor: $M ] ].
	^ self new 
		hours: hour 
		minutes: minute 
		seconds: second 
		milliseconds: nanos / 1000000
	! !

!DateAndTime class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'damiencassou 5/30/2008 10:56'!
fromString: aString 
	^ self readFrom: aString readStream! !

!DateAndTime class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 2/2/2018 15:13'!
readFrom: aStream
	"Parse and return a new DateAndTime instance from stream, 
	as a Date, an optional Time and an optional TimeZone offset.
	The time defaults to midnight, the timezone to the local offset"
	"self readFrom: '2013-03-04T23:47:52.876+01:00' readStream"

	^self readFrom: aStream defaultOffset: self  localTimeZone offset.! !

!DateAndTime class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 2/2/2018 15:43'!
readFrom: aStream defaultOffset: defaultOffset
	"Parse and return a new DateAndTime instance from stream, 
	as a Date, an optional Time and an optional TimeZone offset.
	The time defaults to midnight, the timezone to defaultOffset"
	"self readFrom: '2013-03-04T23:47:52.876+01:00' readStream"

	| date time offset |
	date := Date readFrom: aStream.
	[ aStream atEnd or: [ '0123456789Z+-' includes: aStream peek ] ] 
		whileFalse: [ aStream next ].
  	('0123456789' includes: aStream peek)
		ifTrue: [ time := Time readFrom: aStream ]
		ifFalse: [ time := Time midnight ].
	aStream skipSeparators.
	offset := self readTimezoneOffsetFrom: aStream default: defaultOffset.

^ self
	year: date year
	day: date dayOfYear
	hour: time hours
	minute: time minutes
	second: time seconds
	millisecond: time milliseconds
	offset: offset

! !

!DateAndTime class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'VincentBlondeau 2/25/2016 13:42'!
readOptionalSeparatorFrom: stream
	"Read an optional separator (non decimal digit) from stream and return it.
	Return nil if nothing was read"

	| isDigit |
	stream atEnd
		ifTrue: [ ^ nil ].
	isDigit := '0123456789' includes: stream peek.
	(isDigit or: [ ':' includes: stream peek ])
		ifFalse: [ ^ nil ].
	isDigit
		ifFalse: [ stream next ]! !

!DateAndTime class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'AlistairGrant 6/25/2016 22:47'!
readTimezoneOffsetFrom: stream default: defaultOffset
	"Read and return an optional timezone offset in the form of 
	[+|-]hh[[separator]mm[[separator]ss]] or Z from stream as a duration.
	If there is no offset, return the defaultOffset."

	| sign hour minute second |
	(stream peekFor: $Z) ifTrue: [ ^ Duration zero ].
	hour := minute := second := 0.
	^ ('+-' includes: stream peek)
		ifTrue: [
			sign := stream next = $- ifTrue: [ -1 ] ifFalse: [ 1 ].
			hour := self readTwoDigitIntegerFrom: stream.
			(self readOptionalSeparatorFrom: stream)
				ifNotNil: [ 
					minute := self readTwoDigitIntegerFrom: stream.
					(self readOptionalSeparatorFrom: stream)
						ifNotNil: [ 
							second := Integer readFrom: stream ] ].
			Duration seconds: sign * ((hour * 3600) + (minute * 60) + second) ]
		ifFalse: [ defaultOffset ]! !

!DateAndTime class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'SvenVanCaekenberghe 3/6/2013 16:34'!
readTwoDigitIntegerFrom: stream
	"Parse and return a decimal number of 2 digits from stream.
	Fail if that is not possible"

	| integer |
	integer := 0.
	2 timesRepeat: [ | char |
		char := stream next.
		('0123456789' includes: char) ifFalse: [ self error: 'Decimal digit expected' ].
		integer := (integer * 10) + char digitValue ].
	^ integer! !

!Date class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'TorstenBergmann 8/20/2014 13:19'!
fromString: aString
	"Answer an instance of created from a string with format mm.dd.yyyy or mm-dd-yyyy or mm/dd/yyyy"

	^ self readFrom: aString readStream.! !

!Date class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 2/2/2018 14:54'!
readFrom: aStream 
	"Read a Date from the stream in any of the forms:  
		<day> <month> <year>		(15 April 1982; 15-APR-82; 15.4.82; 15APR82)  
		<month> <day> <year>		(April 15, 1982; 4/15/82)
		<year>-<month>-<day>			(1982-04-15) (ISO8601)"
	| day month year parsedNumber prefix |
	aStream peek = $-
		ifTrue: [prefix := -1]
		ifFalse: [prefix := 1].
	[aStream peek isAlphaNumeric]
		whileFalse: [aStream skip: 1].
	aStream peek isDigit
		ifTrue: [
			parsedNumber := (Integer readFrom: aStream) * prefix.
			(parsedNumber < 0 or: [parsedNumber > 31])
				ifTrue: [year := parsedNumber]].
	[aStream peek isAlphaNumeric]
		whileFalse: [aStream skip: 1].
	aStream peek isLetter
		ifTrue: ["MM-DD-YY or DD-MM-YY or YY-MM-DD"
			month := (String new: 10) writeStream.
			[aStream peek isLetter]
				whileTrue: [month nextPut: aStream next].
			month := month contents.
			[aStream peek isAlphaNumeric]
				whileFalse: [aStream skip: 1].
			parsedNumber 
				ifNil: ["MM DD YY"
					day := Integer readFrom: aStream]
				ifNotNil: [
					year 
						ifNil: ["DD MM YY"
							day := parsedNumber]]]
		ifFalse: ["MM-DD-YY or DD-MM-YY or YY-MM-DD"
			year 
				ifNil: ["MM-DD-YY or DD-MM-YY"
					parsedNumber > 12
						ifTrue: ["DD-MM-YY"
							Error signal: 'Month out of bounds: ', parsedNumber asString, '.'.
							day := parsedNumber.
							month := self nameOfMonth: (Integer readFrom: aStream) ]
						ifFalse: ["MM-DD-YY"
							month := self nameOfMonth: parsedNumber.
							day := Integer readFrom: aStream]]
				ifNotNil: ["YY-MM-DD"
					month := self nameOfMonth: (Integer readFrom: aStream)]].
	[aStream peek isAlphaNumeric]
		whileFalse: [aStream skip: 1].
	year 
		ifNil: [year := Integer readFrom: aStream]
		ifNotNil: [day := Integer readFrom: aStream].
	(year < 100 and: [year >= 0]) 
		ifTrue: [
			year < 69 
				ifTrue: [year := 2000 + year]
				ifFalse: [year := 1900 + year]].

	^ self
		newDay: day
		month: month
		year: year! !

!Date methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 15:37'!
yyyymmdd
	^ String
		streamContents: [ :s | 
			Locale current lcTime copy
				dFmt: '%Y-%m-%d';
				printDate: self on: s ]! !

!Float methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num
 	"Tell whether the receiver and arguments are close from each."
	
	^ self closeTo: num precision: 0.0001! !

!Float methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 11:29'!
closeTo: num precision: aPrecision
 	"Tell whether the receiver and arguments are close from each other given a precision"
	
	num isNumber ifFalse: [ ^ [self = num] ifError: [false]].
	self = 0.0 ifTrue: [^ num abs < aPrecision].
	num = 0 ifTrue: [^self abs < aPrecision].
	^self = num asFloat
		or: [(self - num) abs / (self abs max: num abs) < aPrecision]! !

!Point methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 12:05'!
setX: xValue setY: yValue 
	x := xValue.
	y := yValue! !

!ByteArray class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'StephaneDucasse 2/28/2010 12:04'!
readHexFrom: aString
	"Create a byte array from a hexadecimal representation"
	^(self new: aString size // 2) readHexFrom: aString readStream! !

!ByteArray methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'marianopeck 1/31/2018 15:40'!
hex
    " an alternate implementation was | result stream |
	result := String new: self size * 2.
	stream := result writeStream.
	1 to: self size do: [ :ix | |each|
		each := self at: ix.
		stream
			nextPut: ('0123456789ABCDEF' at: each // 16 + 1);
			nextPut: ('0123456789ABCDEF' at: each \\ 16 + 1)].
    ^ result"
	
	"Answer a hexa decimal representation of the receiver"
	| string v index map |
	map := '0123456789abcdef'.
	string := String new: self size * 2. "hex"
	index := 0.
	1 to: self size do: [ :i |
		v := self at: i.
		string at: (index := index + 1) put: (map at: (v bitShift: -4) + 1).
		string at: (index := index + 1) put: (map at: (v bitAnd: 15) + 1)].
	^string
	! !

!ByteArray methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'StephaneDucasse 2/28/2010 12:03'!
readHexFrom: aStream
	"Initialize the receiver from a hexadecimal string representation"
	| map v ch value |
	map := '0123456789abcdefABCDEF'.
	1 to: self size do: [ :i |
		ch := aStream next.
		v := (map indexOf: ch) - 1.
		((v between: 0 and: 15) or: [((v:= v - 6) between: 0 and: 15)]) ifFalse:[^self error: 'Hex digit 
expected'].
		value := v bitShift: 4.
		ch := aStream next.
		v := (map indexOf: ch) - 1.
		((v between: 0 and: 15) or: [((v:= v - 6) between: 0 and: 15)]) ifFalse:[^self error: 'Hex digit 
expected'].
		value := value + v.
		self at: i put: value].! !

!NeoJSONBenchmark class methodsFor: '*Neo-JSON-VAST-Tests' stamp: 'MarianoMartinezPeck 1/30/2018 10:06'!
new
	^super new initialize! !

!ArrayedCollection class methodsFor: '*Neo-JSON-VAST-Tests' stamp: ''!
new: size withAll: value 
	"Answer an instance of me, with number of elements equal to size, each 
	of which refers to the argument, value."

	^(self new: size) atAllPut: value! !

TestCase subclass: #NeoJSONVASTTest
	instanceVariableNames: 'june2nd1973 time'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Neo-JSON-VAST-Tests'!

!NeoJSONVASTTest methodsFor: 'running' stamp: 'marianopeck 2/2/2018 15:21'!
setUp

	june2nd1973 := Date newDay: 2 monthIndex: 6 year: 1973.
	time := Time fromSeconds: 14567.		"4:02:47 am"! !

!NeoJSONVASTTest methodsFor: 'tests' stamp: 'marianopeck 2/2/2018 15:53'!
testDateAndTimeFromString

	| fromString fromStringNoOffset |
	fromString := DateAndTime fromString: '2018-02-02T15:09:19.664-03:00'.
	self assert: fromString printString equals: '2018-02-02T15:09:19.664-03:00'.
	
	"if no offset is provided, the local offset should be used"
	fromStringNoOffset := DateAndTime fromString: '2018-02-02T15:09:19.664'.
	self assert: fromStringNoOffset offset equals: DateAndTime localTimeZone offset.! !

!NeoJSONVASTTest methodsFor: 'tests' stamp: 'marianopeck 2/2/2018 15:06'!
testDateAndTimeString
! !

!NeoJSONVASTTest methodsFor: 'tests' stamp: 'marianopeck 2/2/2018 15:05'!
testDateFromString
 	"The fromString method requires month, day and year delemited by a valid date delimiter"
	
	| d |
	d := Date fromString: '06.02.1973'. 
	self assert: d equals: june2nd1973.
 
	d := Date fromString: '06-02-1973'. 
	self assert: d equals: june2nd1973.

	d := Date fromString: '06/02/1973'. 
	self assert: d equals: june2nd1973.	! !

!NeoJSONVASTTest methodsFor: 'tests' stamp: 'marianopeck 2/2/2018 15:05'!
testDateReadFrom

	| s1 s2 s3 s4 s5 | 
	s1 := '2 June 1973' readStream.
	s2 := '2-JUN-73' readStream.
	s3 := 'June 2, 1973' readStream.
	s4 := '6/2/73' readStream.
	s5 := '2JUN73' readStream.

	self	
		assert: (Date readFrom: s1) equals: june2nd1973;
		assert: (Date readFrom: s2) equals: june2nd1973;
		assert: (Date readFrom: s3) equals: june2nd1973;
		assert: (Date readFrom: s4) equals: june2nd1973.	! !

!NeoJSONVASTTest methodsFor: 'tests' stamp: 'marianopeck 2/2/2018 15:31'!
testTimeReadFrom
	"self debug: #testReadFrom"
	
	| string t |
	string := '4:02:47 am'.
	t := Time readFrom: string readStream.
	self assert: time printString = t printString.
! !

!NeoJSONVASTTest methodsFor: 'tests' stamp: 'marianopeck 2/2/2018 15:32'!
testTimeReadFromWithError
	"self debug: #testReadFromWithError"
	
	| string |
	string := 'invalid'.
	self should: [Time readFrom: string readStream] raise: Error.
	string := '0:invalid'.
	self should: [Time readFrom: string readStream] raise: Error
! !
